package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Mar 12, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
var (
CmdLine *cmdLineLoggerService
Console *redisConsoleService
)
func Debug(value interface{})
func Error(value interface{})
func Info(value interface{})
func Warn(value interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.